@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Wx;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 # Add Wx::Scintilla distribution directory to PATH on windows so that Wx can load it
 my $wx_scintilla_path;
@@ -33,13 +33,16 @@ XSLoader::load 'Wx::Scintilla', $VERSION;
 
 no strict;
 
-package Wx::ScintillaTextCtrl; our $VERSION = '0.08'; @ISA = qw(Wx::Control);
+package Wx::ScintillaTextCtrl; our $VERSION = '0.09'; @ISA = qw(Wx::Control);
 
-package Wx::ScintillaTextEvent; our $VERSION = '0.08'; @ISA = qw(Wx::CommandEvent);
+package Wx::ScintillaTextEvent; our $VERSION = '0.09'; @ISA = qw(Wx::CommandEvent);
 
-#TODO uncomment when the CPAN permission issue is resolved
-#package Wx::Event;
-#our $VERSION = '0.08'
+#Defeat the indexer by splitting the package declaration on two lines
+#<<<  do not let perltidy touch this
+package
+	Wx::Event;
+#>>>
+our $VERSION = '0.09';
 
 use strict;
 
